import { ActivatedRoute, ActivatedRouteSnapshot, Data, Params, Route, UrlSegment } from '@angular/router';
import { Observable } from 'rxjs';
import { Type } from '@angular/core';
/**
 * Creates a fake partial ActivatedRoute for tests.
 *
 * If you pass params, then the created route's paramMap will contain the same values.
 * The same goes for queryParams and queryParamMap.
 *
 * If you pass a parent route and a snapshot, and the passed snapshot doesn't have a parent, then the snapshot's
 * parent will be set to the parent route snapshot. This allows the code under test to use
 * `route.parent.snapshot` or `route.snapshot.parent`.
 *
 * If you pass a snapshot with a parent, but don't pass a parent or pass a parent without snapshot, then the route's
 * parent snapshot will be set to the given snapshot's parent. This allows the code under test to use
 * `route.parent.snapshot` or `route.snapshot.parent`.
 *
 * @returns a partially populated, fake ActivatedRoute, depending on what you passed in
 * @deprecated favor stubRoute, which creates an easier to use and more logical stub
 */
export declare function fakeRoute(options: {
    url?: Observable<UrlSegment[]>;
    /** An observable of the matrix parameters scoped to this route */
    params?: Observable<Params>;
    /** An observable of the query parameters shared by all the routes */
    queryParams?: Observable<Params>;
    /** An observable of the URL fragment shared by all the routes */
    fragment?: Observable<string>;
    /** An observable of the static and resolved data of this route. */
    data?: Observable<Data>;
    /** The outlet name of the route. It's a constant */
    outlet?: string;
    /** The component of the route. It's a constant */
    component?: Type<unknown> | string | null;
    /** The current snapshot of this route */
    snapshot?: ActivatedRouteSnapshot;
    /** The configuration used to match this route */
    routeConfig?: Route | null;
    /** The root of the router state */
    root?: ActivatedRoute;
    /** The parent of this route in the router state tree */
    parent?: ActivatedRoute | null;
    /** The first child of this route in the router state tree */
    firstChild?: ActivatedRoute;
    /** The children of this route in the router state tree */
    children?: ActivatedRoute[];
    /** The path from the root of the router state tree to this route */
    pathFromRoot?: ActivatedRoute[];
}): ActivatedRoute;
/**
 * Creates a fake partial ActivatedRouteSnapshot for tests.
 *
 * If you pass params, then the created snapshot's paramMap will contain the same values.
 * The same goes for queryParams and queryParamMap.
 *
 * @returns a partially populated, fake ActivatedRoute, depending on what you passed in
 * @deprecated favor stubRoute, which creates an easier to use and more logical stub for both the route and its snapshot
 */
export declare function fakeSnapshot(options: {
    url?: UrlSegment[];
    /** The matrix parameters scoped to this route */
    params?: Params;
    /** The query parameters shared by all the routes */
    queryParams?: Params;
    /** The URL fragment shared by all the routes */
    fragment?: string;
    /** The static and resolved data of this route */
    data?: Data;
    /** The outlet name of the route */
    outlet?: string;
    /** The component of the route */
    component?: Type<unknown> | string | null;
    /** The configuration used to match this route */
    routeConfig?: Route;
    /** The root of the router state */
    root?: ActivatedRouteSnapshot;
    /** The parent of this route in the router state tree */
    parent?: ActivatedRouteSnapshot | null;
    /** The first child of this route in the router state tree */
    firstChild?: ActivatedRouteSnapshot | null;
    /** The children of this route in the router state tree */
    children?: ActivatedRouteSnapshot[];
    /** The path from the root of the router state tree to this route */
    pathFromRoot?: ActivatedRouteSnapshot[];
}): ActivatedRouteSnapshot;
/**
 * The options that are passed when creating an ActivatedRouteStub.
 */
export interface ActivatedRouteStubOptions {
    /**
     * The initial values of the parameters of the route
     */
    params?: Params;
    /**
     * The initial values of the query parameters of the route
     */
    queryParams?: Params;
    /**
     * The initial values of the data of the route
     */
    data?: Data;
    /**
     * The initial fragment of the route
     */
    fragment?: string | null;
    /**
     * The initial url of the route
     */
    url?: UrlSegment[];
    /**
     * The parent of the route
     */
    parent?: ActivatedRouteStub | null;
    /**
     * The first child of the route
     */
    firstChild?: ActivatedRouteStub | null;
    /**
     * The children of the route
     */
    children?: ActivatedRouteStub[] | null;
    /**
     * The configuration of the route
     */
    routeConfig?: Route | null;
}
/**
 * A stub for ActivatedRoute. It behaves almost the same way as the actual ActivatedRoute, exposing a snapshot
 * and observables for the params, query params etc., which are kept in sync.
 *
 * In addition, this stub allows simulating a navigation by changing the params, the query params, the fragment, etc.
 * When that happens, the snapshot is modified, then the relevant observables emit the new values.
 *
 * There are some things that don't really work the same way as the real ActivatedRoute though:
 * - the handling of the firstChild and of the children is entirely under the tester's responsibility. Setting the parent
 *   of a route stub does not add this route to the children of its parent, for example.
 * - when changing the params, query params, fragment, etc., their associated observable emits unconditionally, instead of
 *   first checking if the value is actually different from before. It's thus the responsibility of the tester to not
 *   change the values if they're the same as before.
 * - the params, paramMap, queryParams and queryParamMap objects of the route snapshot change when params or query params are set
 *   on the stub route. So if the code keeps a reference to params or paramMaps, it won't see the changes.
 */
export declare class ActivatedRouteStub extends ActivatedRoute {
    private _firstChild;
    private _children;
    private readonly paramsSubject;
    private readonly queryParamsSubject;
    private readonly dataSubject;
    private readonly fragmentSubject;
    private readonly urlSubject;
    private _parent;
    private _root;
    private _pathFromRoot;
    /**
     * Constructs a new instance, based on the given options.
     * If an option is not provided (or if no option is provided at all), then the route has a default value for this option
     * (empty parameters for example, null fragment, etc.)
     * If no parent is passed, then this route has no parent and is thus set as the root. Otherwise, the root and the path
     * from root are created based on the root and path from root of the given parent route.
     */
    constructor(options?: ActivatedRouteStubOptions);
    get root(): ActivatedRouteStub;
    get parent(): ActivatedRouteStub | null;
    get pathFromRoot(): Array<ActivatedRouteStub>;
    get firstChild(): ActivatedRouteStub | null;
    get children(): Array<ActivatedRouteStub>;
    get routeConfig(): Route | null;
    /**
     * Triggers a navigation with the given new parameters. All the other parts (query params etc.) stay as the are.
     * This is a shortcut to `triggerNavigation` that can be used to only change the parameters.
     */
    setParams(params: Params): void;
    /**
     * Triggers a navigation with the given new parameter. The other parameters, as well as all the other parts (query params etc.)
     * stay as the are.
     * This is a shortcut to `triggerNavigation` that can be used to only change one parameter.
     */
    setParam(name: string, value: string): void;
    /**
     * Triggers a navigation with the given new query parameters. All the other parts (params etc.) stay as the are.
     * This is a shortcut to `triggerNavigation` that can be used to only change the query parameters.
     */
    setQueryParams(queryParams: Params): void;
    /**
     * Triggers a navigation with the given new parameter. The other query parameters, as well as all the other parts (params etc.)
     * stay as the are.
     * This is a shortcut to `triggerNavigation` that can be used to only change one query parameter.
     */
    setQueryParam(name: string, value: string): void;
    /**
     * Triggers a navigation with the given new data. The other parameters, as well as all the other parts (params etc.)
     * stay as the are.
     * This is a shortcut to `triggerNavigation` that can be used to only change the data.
     */
    setData(data: Data): void;
    /**
     * Triggers a navigation with the given new data item. The other data, as well as all the other parts (params etc.)
     * stay as the are.
     * This is a shortcut to `triggerNavigation` that can be used to only change one data item.
     */
    setDataItem(name: string, value: unknown): void;
    /**
     * Triggers a navigation with the given new fragment. The other parts (params etc.)  stay as the are.
     * This is a shortcut to `triggerNavigation` that can be used to only change the fragment.
     */
    setFragment(fragment: string | null): void;
    /**
     * Triggers a navigation with the given new url. The other parts (params etc.)  stay as the are.
     * This is a shortcut to `triggerNavigation` that can be used to only change the url.
     */
    setUrl(url: Array<UrlSegment>): void;
    /**
     * Triggers a navigation based on the given options. If an option is undefined or null, it's ignored. Except for fragment, which is only
     * ignored if it's undefined, because null is a valid value for a fragment.
     *
     * The non-ignored values are used to change the snapshot of the route. Once the snapshot has been modified,
     * the observables corresponding to the updated parts emit the new value.
     *
     * So, setting params and query params will make the params and queryParams observables emit, but not the fragment, data and
     * url observables for example. This is consistent to how the router behaves.
     */
    triggerNavigation(options: {
        params?: Params;
        queryParams?: Params;
        fragment?: string | null;
        data?: Data | null;
        url?: Array<UrlSegment> | null;
    }): void;
    toString(): string;
}
/**
 * Creates a new ActivatedRouteStub, by calling its constructor.
 */
export declare function stubRoute(options?: ActivatedRouteStubOptions): ActivatedRouteStub;
