import { TestButton } from './test-button';
import { TestSelect } from './test-select';
import { TestElement } from './test-element';
import { TestTextArea } from './test-textarea';
import { TestInput } from './test-input';
import { ComponentTester } from './component-tester';
import { DebugElement, Type } from '@angular/core';
/**
 * @internal
 */
export declare class TestElementQuerier {
    private tester;
    private root;
    constructor(tester: ComponentTester<unknown>, root: DebugElement);
    static wrap(childDebugElement: DebugElement, tester: ComponentTester<unknown>): TestElement;
    /**
     * Gets the first element matching the given selector and wraps it into a TestElement. The actual type
     * of the returned value is the TestElement subclass matching the type of the found element. So, if the
     * matched element is an input for example, the method will return a TestInput. You can thus use
     * `tester.element('#some-input') as TestInput`.
     * @param selector a CSS or directive selector
     * @returns the wrapped element, or null if no element matches the selector.
     */
    element(selector: string | Type<any>): TestElement | null;
    /**
     * Gets all the elements matching the given selector and wraps them into a TestElement. The actual type
     * of the returned elements is the TestElement subclass matching the type of the found element. So, if the
     * matched elements are inputs for example, the method will return an array of TestInput. You can thus use
     * `tester.elements('input') as Array<TestInput>`.
     * @param selector a CSS or directive selector
     * @returns the array of matched elements, empty if no element was matched
     */
    elements(selector: string | Type<any>): Array<TestElement>;
    /**
     * Gets the first input matched by the given selector. Throws an Error if the matched element isn't actually an input.
     * @param selector a CSS or directive selector
     * @returns the wrapped input, or null if no element was matched
     */
    input(selector: string | Type<any>): TestInput | null;
    /**
     * Gets the first select matched by the given selector. Throws an Error if the matched element isn't actually a select.
     * @param selector a CSS or directive selector
     * @returns the wrapped select, or null if no element was matched
     */
    select(selector: string | Type<any>): TestSelect | null;
    /**
     * Gets the first textarea matched by the given selector
     * @param selector a CSS or directive selector
     * @returns the wrapped textarea, or null if no element was matched. Throws an Error if the matched element isn't actually a textarea.
     * @throws {Error} if the matched element isn't actually a textarea
     */
    textarea(selector: string | Type<any>): TestTextArea | null;
    /**
     * Gets the first button matched by the given selector. Throws an Error if the matched element isn't actually a button.
     * @param selector a CSS or directive selector
     * @returns the wrapped button, or null if no element was matched
     */
    button(selector: string | Type<any>): TestButton | null;
    private query;
    private queryAll;
}
