import { ComponentTester } from './component-tester';
import { TestHtmlElement } from './test-html-element';
import { DebugElement } from '@angular/core';
/**
 * A wrapped DOM HTML select element, providing additional methods and attributes helping with writing tests
 */
export declare class TestSelect extends TestHtmlElement<HTMLSelectElement> {
    constructor(tester: ComponentTester<unknown>, debugElement: DebugElement);
    /**
     * Selects the option at the given index, then dispatches an event of type change and triggers a change detection
     */
    selectIndex(index: number): void;
    /**
     * Selects the first option with the given value, then dispatches an event of type change and triggers a change detection.
     * If there is no option with the given value, then does nothing
     * TODO should it throw instead?
     */
    selectValue(value: string): void;
    /**
     * Selects the first option with the given label (or text), then dispatches an event of type change and triggers a change detection.
     * If there is no option with the given label, then does nothing
     * TODO should it throw instead?
     */
    selectLabel(label: string): void;
    /**
     * the selected index of the wrapped select
     */
    get selectedIndex(): number;
    /**
     * the value of the selected option of the wrapped select, or null if there is no selected option
     */
    get selectedValue(): string | null;
    /**
     * the label (or text if no label) of the selected option of the wrapped select, or null if there is no selected option
     */
    get selectedLabel(): string | null;
    /**
     * the values of the options, as an array
     */
    get optionValues(): Array<string>;
    /**
     * the labels (or texts if no label) of the options, as an array
     */
    get optionLabels(): Array<string>;
    /**
     * the number of options in the select
     */
    get size(): number;
    /**
     * the disabled property of the wrapped select
     */
    get disabled(): boolean;
}
